import setuptools


setuptools.setup(
    name="share121",
    version="0.0.1",
    author="May.T",
    author_email="1355228926@qq.com",
    description="for homework",
    long_description_content_type="text/markdown",
    url="http://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)

